@@ -1,6 +1,6 @@
 package Acme::CPANAuthors::DualLife;
 BEGIN {
-  $Acme::CPANAuthors::DualLife::VERSION = '0.02';
+  $Acme::CPANAuthors::DualLife::VERSION = '0.04';
 }
 
 #ABSTRACT: We are CPAN Authors of Dual Life core modules
@@ -14,7 +14,6 @@ use Acme::CPANAuthors::Register (
   ANDK => q[Andreas J. Koenig],
   ANDYA => q[Andy Armstrong],
   AUDREYT => q[Audrey Tang],
-  BDFOY => q[brian d foy],
   BINGOS => q[Chris Williams],
   CHORNY => q[Alexandr Ciornii],
   CORION => q[Max Maischein],
@@ -72,6 +71,7 @@ use Acme::CPANAuthors::Register (
   TODDR => q[Todd Rinaldo],
   TOMHUGHES => q[Tom Hughes],
   YVES => q[Yves],
+  ZEFRAM => q[Andrew Main (Zefram)],
 );
 
 q[Dual life better than Real life];
@@ -86,7 +86,7 @@ Acme::CPANAuthors::DualLife - We are CPAN Authors of Dual Life core modules
 
 =head1 VERSION
 
-version 0.02
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -114,7 +114,6 @@ It is currently statically generated information, I hope to make it dynamic in t
   ANDK => q[Andreas J. Koenig],
   ANDYA => q[Andy Armstrong],
   AUDREYT => q[Audrey Tang],
-  BDFOY => q[brian d foy],
   BINGOS => q[Chris Williams],
   CHORNY => q[Alexandr Ciornii],
   CORION => q[Max Maischein],
@@ -172,6 +171,7 @@ It is currently statically generated information, I hope to make it dynamic in t
   TODDR => q[Todd Rinaldo],
   TOMHUGHES => q[Tom Hughes],
   YVES => q[Yves],
+  ZEFRAM => q[Andrew Main (Zefram)],
 
 =head1 SEE ALSO
 
